package org.hashtree.jbrainhoney.dlap.command;

import org.hashtree.jbrainhoney.dlap.validate.EntityIdAttributeValidator;
import org.hashtree.jbrainhoney.dlap.validate.UserspaceAttributeValidator;

/**
 * A command which lists domains. See the
 * {@link <a href="http://gls.agilix.com/Docs/Command/GetDomainList">the BrainHoney DLAP API guide</a>} for this
 * command.
 */
public final class GetDomainListCommand implements Command {
	private final String domainId;
	private final String name;
	private final String userspace;

	@SuppressWarnings("synthetic-access")
	private GetDomainListCommand(final Builder builder) throws IllegalArgumentException {
		if(builder.domainId != null && !EntityIdAttributeValidator.getInstance().isValid(builder.domainId))
			throw new IllegalArgumentException("Expected domainId to be valid.");
		else if(builder.userspace != null && !UserspaceAttributeValidator.getInstance().isValid(builder.userspace))
			throw new IllegalArgumentException("Expected userspace to be valid.");

		domainId = builder.domainId;
		name = builder.name;
		userspace = builder.userspace;
	}

	public String getDomainId() {
		return domainId;
	}

	public String getName() {
		return name;
	}

	public String getUserspace() {
		return userspace;
	}

	/** A builder of immutable GetDomainListCommand instances. */
	public final static class Builder implements Command.Builder {
		private String domainId;
		private String name;
		private String userspace;

		public Builder() {
			super();
		}

		public Builder setDomainId(final String domainId) {
			this.domainId = domainId;

			return this;
		}

		public Builder setDomainId(final Integer domainId) {
			this.domainId = (domainId == null ? null : domainId.toString());

			return this;
		}

		public Builder setName(final String name) {
			this.name = name;

			return this;
		}

		public Builder setUserspace(final String userspace) {
			this.userspace = userspace;

			return this;
		}

		@Override
		@SuppressWarnings("synthetic-access")
		public GetDomainListCommand build() {
			return new GetDomainListCommand(this);
		}
	}
}