package org.hashtree.jbrainhoney.dlap.command;

import org.hashtree.jbrainhoney.dlap.validate.EntityIdAttributeValidator;

/**
 * A command which lists groups that the specified enrollment is a member of. See the
 * {@link <a href="http://gls.agilix.com/Docs/Command/GetEnrollmentGroupList">the BrainHoney DLAP API guide</a>} for
 * this command.
 */
public final class GetEnrollmentGroupListCommand implements Command {
	private final String enrollmentId;

	@SuppressWarnings("synthetic-access")
	private GetEnrollmentGroupListCommand(final Builder builder) throws IllegalArgumentException {
		if(builder.enrollmentId == null) throw new IllegalArgumentException("Expected enrollmentId to not be null.");
		else if(!EntityIdAttributeValidator.getInstance().isValid(builder.enrollmentId))
			throw new IllegalArgumentException("Expected enrollmentId to be valid.");

		enrollmentId = builder.enrollmentId;
	}

	public String getEnrollmentId() {
		return enrollmentId;
	}

	/** A builder of immutable GetEnrollmentGroupListCommand instances. */
	public final static class Builder implements Command.Builder {
		private final String enrollmentId;

		public Builder(final String enrollmentId) {
			super();

			this.enrollmentId = enrollmentId;
		}

		public Builder(final Integer enrollmentId) {
			super();

			this.enrollmentId = (enrollmentId == null ? null : enrollmentId.toString());
		}

		@Override
		@SuppressWarnings("synthetic-access")
		public GetEnrollmentGroupListCommand build() {
			return new GetEnrollmentGroupListCommand(this);
		}
	}
}