package org.hashtree.jbrainhoney.dlap.command;

import org.hashtree.jbrainhoney.dlap.validate.EntityIdAttributeValidator;

/**
 * A command which lists groups. See the
 * {@link <a href="http://gls.agilix.com/Docs/Command/GetGroupList">the BrainHoney DLAP API guide</a>} for this command.
 */
public final class GetGroupListCommand implements Command {
	private final String ownerId;
	private final Integer setId;

	@SuppressWarnings("synthetic-access")
	private GetGroupListCommand(final Builder builder) throws IllegalArgumentException {
		if(builder.ownerId == null) throw new IllegalArgumentException("Expected ownerId to not be null.");
		else if(!EntityIdAttributeValidator.getInstance().isValid(builder.ownerId))
			throw new IllegalArgumentException("Expected ownerId to be valid.");
		else if(builder.setId != null && builder.setId <= 0)
			throw new IllegalArgumentException("Expected setId to be greater than 0.");

		ownerId = builder.ownerId;
		setId = builder.setId;
	}

	public String getOwnerId() {
		return ownerId;
	}

	public Integer getSetId() {
		return setId;
	}

	/** A builder of immutable GetGroupListCommand instances. */
	public final static class Builder implements Command.Builder {
		private final String ownerId;
		private Integer setId;

		public Builder(final String ownerId) {
			super();

			this.ownerId = ownerId;
		}

		public Builder(final Integer ownerId) {
			super();

			this.ownerId = (ownerId == null ? null : ownerId.toString());
		}

		public Builder setSetId(final Integer setId) {
			this.setId = setId;

			return this;
		}

		@Override
		@SuppressWarnings("synthetic-access")
		public GetGroupListCommand build() {
			return new GetGroupListCommand(this);
		}
	}
}