package org.hashtree.jbrainhoney.dlap.command;

import java.util.Collections;
import java.util.HashSet;
import java.util.Set;

/** An implementation of CommandObserverManager for classes implementing the SessionObserver interface. */
public final class SessionObserverManager implements CommandObserverManager<SessionObserver, SessionEvent> {
	private Set<SessionObserver> observers;

	public SessionObserverManager() {
		observers = Collections.synchronizedSet(new HashSet<SessionObserver>());
	}

	@Override
	public boolean addObserver(final SessionObserver observer) throws IllegalArgumentException {
		if(observer == null) throw new IllegalArgumentException("Expected observer to not be null.");

		return observers.add(observer);
	}

	@Override
	public boolean removeObserver(final SessionObserver observer) throws IllegalArgumentException {
		if(observer == null) throw new IllegalArgumentException("Expected observer to not be null.");

		return observers.remove(observer);
	}

	@Override
	public boolean hasObserver(final SessionObserver observer) throws IllegalArgumentException {
		if(observer == null) throw new IllegalArgumentException("Expected observer to not be null.");

		return observers.contains(observer);
	}

	@Override
	public SessionObserverManager notifyObservers(final SessionEvent event) {
		synchronized(observers) {
			for(SessionObserver observer : observers) {
				if(observer != null) observer.notify(event);
			}
		}

		return this;
	}
}