package org.hashtree.jbrainhoney.dlap.enumeration;

import java.util.EnumSet;
import org.hashtree.jbrainhoney.dlap.element.Course;
import org.hashtree.jbrainhoney.dlap.element.Domain;
import org.hashtree.jbrainhoney.dlap.element.Entity;
import org.hashtree.jbrainhoney.dlap.element.Group;
import org.hashtree.jbrainhoney.dlap.element.Section;

/** Enumerates entity types. */
public enum EntityType implements ClassLiteralEnumeration<Entity> {
	COURSE(Course.class),
	DOMAIN(Domain.class),
	GROUP(Group.class),
	SECTION(Section.class);

	private final Class<? extends Entity> classLiteral;

	private EntityType(final Class<? extends Entity> classLiteral) {
		this.classLiteral = classLiteral;
	}

	@Override
	public Class<? extends Entity> getClassLiteral() {
		return classLiteral;
	}

	public static EntityType valueOfClassLiteral(final Class<? extends Entity> classLiteral)
		throws IllegalArgumentException {

		if(classLiteral == null) throw new IllegalArgumentException("Expected classLiteral to not be null.");

		EntityType enumeration = null;

		for(EntityType element : EnumSet.allOf(EntityType.class)) {
			if(element.getClassLiteral() != null && element.getClassLiteral().equals(classLiteral)){
				enumeration = element;
				break;
			}
		}

		if(enumeration == null) throw new IllegalArgumentException("Expected classLiteral match.");

		return enumeration;
	}
}