package org.hashtree.jbrainhoney.network.http.request;

import java.io.File;

/** A file based implementation of a Body.*/
public final class FileBody implements Body {
	private static final long serialVersionUID = -8845294630572913L;
	private final File value;
	private final String mimeType;

	@SuppressWarnings("synthetic-access")
	private FileBody(final Builder builder) throws IllegalArgumentException {
		if(builder.mimeType == null) throw new IllegalArgumentException("Expected mimeType to not be null.");
		else if(builder.mimeType.trim().length() == 0)
			throw new IllegalArgumentException("Expected mimeType to have a length greater than 0.");
		else if(builder.value == null) throw new IllegalArgumentException("Expected value to not be null.");

		value = builder.value;
		mimeType = builder.mimeType;
	}

	@Override
	public final File getValue() {
		return value;
	}

	@Override
	public final String getMimeType() {
		return mimeType;
	}

	@Override
	public final boolean equals(final Object object) {
		if(object == this) return true;
		else if(!(object instanceof FileBody)) return false;
		else return toString().equals(((FileBody)object).toString());
	}

	@Override
	public final int hashCode() {
		int hashCode = 17;
		hashCode = (31 * hashCode) + (toString() != null ? toString().hashCode() : 0);

		return hashCode;
	}

	@Override
	public final String toString() {
		return FileBody.class.getSimpleName() + "(" + "mimeType=" + mimeType + (value != null ? ", value=" + value.toString() : "") + ")";
	}

	/** A builder of immutable FileBody instances. */
	public static class Builder implements Body.Builder {
		private final File value;
		private final String mimeType;

		public Builder(final File value, final String mimeType) {
			this.value = value;
			this.mimeType = mimeType;
		}

		@Override
		@SuppressWarnings("synthetic-access")
		public FileBody build() {
			return new FileBody(this);
		}
	}
}