package org.hashtree.jbrainhoney.network.http.request;

import org.hashtree.jbrainhoney.network.http.HttpUri;

/** A get based implementation of a HttpRequest. */
public final class GetRequest implements HttpRequest {
	private static final long serialVersionUID = -554028693659112L;
	private final HttpUri uri;

	@SuppressWarnings("synthetic-access")
	private GetRequest(final Builder builder) throws IllegalArgumentException {
		if(builder.uri == null) throw new IllegalArgumentException("Expected uri to not be null.");

		uri = builder.uri;
	}

	@Override
	public HttpUri getUri() {
		return uri;
	}

	@Override
	public boolean equals(final Object object) {
		if(object == this) return true;
		else if(!(object instanceof GetRequest)) return false;
		else return toString().equals(((GetRequest)object).toString());
	}

	@Override
	public int hashCode() {
		int hashCode = 17;
		hashCode = (31 * hashCode) + (toString() != null ? toString().hashCode() : 0);

		return hashCode;
	}

	@Override
	public String toString() {
		return GetRequest.class.getSimpleName() + "(" + "uri=" + uri.toString() + ")";
	}

	/** A builder of immutable GetRequest instances. */
	public final static class Builder implements HttpRequest.Builder {
		private final HttpUri uri;

		public Builder(final HttpUri uri) {
			this.uri = uri;
		}

		@Override
		@SuppressWarnings("synthetic-access")
		public GetRequest build() {
			return new GetRequest(this);
		}
	}
}
